[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
410/418: gnu: texlive-xindy: Use TEXLIVE-BUILD-SYSTEM and related tools.
From: |
guix-commits |
Subject: |
410/418: gnu: texlive-xindy: Use TEXLIVE-BUILD-SYSTEM and related tools. |
Date: |
Fri, 2 Jun 2023 17:26:03 -0400 (EDT) |
ngz pushed a commit to branch tex-team-next
in repository guix.
commit df6a149f198236311c22ec481426e1e9b80ec283
Author: Nicolas Goaziou <mail@nicolasgoaziou.fr>
AuthorDate: Sat May 20 09:45:22 2023 +0200
gnu: texlive-xindy: Use TEXLIVE-BUILD-SYSTEM and related tools.
* gnu/packages/tex.scm (texlive-xindy)[source]: Use TEXLIVE-ORIGIN.
[build-system]: Use TEXLIVE-BUILD-SYSTEM.
[arguments]<#:phases>: Also set Perl executable location in scripts.
---
gnu/packages/tex.scm | 71 +++++++++++++++++++++++++---------------------------
1 file changed, 34 insertions(+), 37 deletions(-)
diff --git a/gnu/packages/tex.scm b/gnu/packages/tex.scm
index c73a3943a8..e3f60a6baf 100644
--- a/gnu/packages/tex.scm
+++ b/gnu/packages/tex.scm
@@ -12172,49 +12172,46 @@ handle complex tests.")
(define-public texlive-xindy
(package
(name "texlive-xindy")
- (version "2.5.1")
- (source (origin
- (method url-fetch)
- (uri (string-append "mirror://ctan/indexing/xindy/base/xindy-"
- version ".tar.gz"))
- (sha256
- (base32
- "0hxsx4zw19kmixkmrln17sxgg1ln4pfp4lpfn5v5fyr1nwfyk3ic"))))
- (build-system gnu-build-system)
+ (version (number->string %texlive-revision))
+ (source (texlive-origin
+ name version
+ (list "doc/man/man1/tex2xindy.1"
+ "doc/man/man1/tex2xindy.man1.pdf"
+ "doc/man/man1/texindy.1"
+ "doc/man/man1/texindy.man1.pdf"
+ "doc/man/man1/xindy.1"
+ "doc/man/man1/xindy.man1.pdf"
+ "doc/xindy/"
+ "scripts/xindy/"
+ "xindy/")
+ (base32
+ "0rgzckyy6w4rmgxins5kakllkpn2hrccaps7lwb8h2nzvd29yj3m")))
+ (outputs '("out" "doc"))
+ (build-system texlive-build-system)
(arguments
(list
- #:configure-flags #~(list "--enable-docs")
#:phases
#~(modify-phases %standard-phases
- (add-after 'unpack 'patch-clisp
+ (add-after 'unpack 'patch-inputs
(lambda* (#:key inputs #:allow-other-keys)
- ;; The xindy.in file is encoded in ISO-8859-1 (or iso-latin-1).
- (with-fluids ((%default-port-encoding "ISO-8859-1"))
- (substitute* "user-commands/xindy.in"
- (("(our \\$clisp = ).*" _ head)
- (format #f "our $clisp = ~s;~%"
- (search-input-file inputs "bin/clisp"))))))))))
- (native-inputs (list clisp
- glibc-locales
- perl
- texlive-bin
- texlive-greek-fontenc
- texlive-hyperref
- texlive-latex-base
- texlive-cyrillic
- texlive-geometry
- (texlive-updmap.cfg ;fonts
- (list texlive-cbfonts
- texlive-lh
- texlive-jknapltx))))
- (inputs (list clisp perl)) ;used at run time
- (home-page "https://www.ctan.org/pkg/xindy")
+ (with-directory-excursion "scripts/xindy/"
+ ;; The scripts are encoded in ISO-8859-1 (or iso-latin-1).
+ (with-fluids ((%default-port-encoding "ISO-8859-1"))
+ (substitute* (list "texindy.pl" "xindy.pl")
+ (("our \\$clisp = .*")
+ (format #f "our $clisp = ~s;~%"
+ (search-input-file inputs "/bin/clisp")))
+ (("/usr/bin/env perl")
+ (search-input-file inputs "/bin/perl"))))))))))
+ (inputs (list clisp perl))
+ (home-page "https://ctan.org/pkg/xindy")
(synopsis "General-purpose index processor")
- (description "Xindy was developed after an impasse had been encountered in
-the attempt to complete internationalisation of @command{makeindex}. Xindy
-can be used to process indexes for documents marked up using (La)TeX, Nroff
-family and SGML-based languages. Xindy is highly configurable, both in markup
-terms and in terms of the collating order of the text being processed.")
+ (description
+ "Xindy was developed after an impasse had been encountered in the attempt
+to complete internationalisation of @command{makeindex}. Xindy can be used to
+process indexes for documents marked up using (La)TeX, Nroff family and
+SGML-based languages. Xindy is highly configurable, both in markup terms and
+in terms of the collating order of the text being processed.")
(license license:gpl2+)))
(define-public texlive-nth
- 323/418: gnu: texlive-latexconfig: Refresh package definition., (continued)
- 323/418: gnu: texlive-latexconfig: Refresh package definition., guix-commits, 2023/06/02
- 325/418: gnu: texlive-kpathsea: Refresh package definition., guix-commits, 2023/06/02
- 342/418: gnu: texlive-cm: Refresh package definition., guix-commits, 2023/06/02
- 341/418: gnu: texlive-cm-lgc: Refresh package definition., guix-commits, 2023/06/02
- 353/418: gnu: Add texlive-manfnt-font., guix-commits, 2023/06/02
- 358/418: gnu: texlive-latex-base: Refresh package definition., guix-commits, 2023/06/02
- 361/418: gnu: simple-texlive-package: Turn it into a stub., guix-commits, 2023/06/02
- 394/418: gnu: texlive-mflogo-font: Fix build., guix-commits, 2023/06/02
- 397/418: gnu: texlive-amsfonts: Fix build., guix-commits, 2023/06/02
- 401/418: gnu: texlive-stmaryrd: Fix build., guix-commits, 2023/06/02
- 410/418: gnu: texlive-xindy: Use TEXLIVE-BUILD-SYSTEM and related tools.,
guix-commits <=
- 415/418: gnu: Add texlive-mfware., guix-commits, 2023/06/02
- 417/418: gnu: texlive-texmf: Improve package style., guix-commits, 2023/06/02
- 156/418: gnu: texlive-datetime2: Refresh package definition., guix-commits, 2023/06/02
- 231/418: gnu: texlive-babel-french: Refresh package definition., guix-commits, 2023/06/02
- 240/418: gnu: texlive-makecmds: Refresh package definition., guix-commits, 2023/06/02
- 225/418: gnu: Add texlive-xmltexconfig., guix-commits, 2023/06/02
- 245/418: gnu: texlive-polyglossia: Refresh package definition., guix-commits, 2023/06/02
- 256/418: gnu: texlive-numprint: Refresh package definition., guix-commits, 2023/06/02
- 258/418: gnu: texlive-bigintcalc: Refresh package definition., guix-commits, 2023/06/02
- 260/418: gnu: texlive-etexcmds: Refresh package definition., guix-commits, 2023/06/02